@@ -145,7 +145,6 @@ protected:
     spider_fields *fields
   );
 public:
-#ifdef HANDLER_HAS_DIRECT_AGGREGATE
   int open_item_sum_func(
     Item_sum *item_sum,
     ha_spider *spider,
@@ -155,12 +154,10 @@ public:
     bool use_fields,
     spider_fields *fields
   ) override;
-#endif
   int append_escaped_util(
     spider_string *to,
     String *from
   ) override;
-#ifdef SPIDER_HAS_GROUP_BY_HANDLER
   int append_tables_top_down_check(
     TABLE_LIST *table_list,
     TABLE_LIST **used_table_list,
@@ -190,7 +187,6 @@ public:
   int append_having(
     spider_string *str
   ) override;
-#endif
   bool tables_on_different_db_are_joinable() override;
   bool socket_has_default_value() override;
   bool database_has_default_value() override;
@@ -324,11 +320,9 @@ public:
     int mode,
     ha_rows &records
   );
-#ifdef HA_HAS_CHECKSUM_EXTENDED
   int fetch_table_checksum(
     ha_spider *spider
   );
-#endif
   int fetch_table_cardinality(
     int mode,
     TABLE *table,
@@ -352,7 +346,6 @@ public:
     longlong pos
   );
   int get_errno();
-#ifdef SPIDER_HAS_DISCOVER_TABLE_STRUCTURE
   int fetch_columns_for_discover_table_structure(
     spider_string *str,
     CHARSET_INFO *access_charset
@@ -366,7 +359,6 @@ public:
     SPIDER_SHARE *spider_share,
     CHARSET_INFO *access_charset
   );
-#endif
 };
 
 class spider_db_mysql_result: public spider_db_mbase_result
@@ -400,12 +392,6 @@ public:
   const char     *lock_table_hash_func_name;
   const char     *lock_table_hash_file_name;
   ulong          lock_table_hash_line_no;
-  DYNAMIC_ARRAY  handler_open_array;
-  bool           handler_open_array_inited;
-  uint           handler_open_array_id;
-  const char     *handler_open_array_func_name;
-  const char     *handler_open_array_file_name;
-  ulong          handler_open_array_line_no;
   spider_db_mbase(
     SPIDER_CONN *conn,
     spider_db_mbase_util *spider_db_mbase_utility
@@ -566,54 +552,6 @@ public:
     uint binlog_pos_length,
     SPIDER_DB_RESULT **res
   );
-#if defined(HS_HAS_SQLCOM) && defined(HAVE_HANDLERSOCKET)
-  int append_sql(
-    char *sql,
-    ulong sql_length,
-    st_spider_db_request_key *request_key
-  );
-  int append_open_handler(
-    uint handler_id,
-    const char *db_name,
-    const char *table_name,
-    const char *index_name,
-    const char *sql,
-    st_spider_db_request_key *request_key
-  );
-  int append_select(
-    uint handler_id,
-    spider_string *sql,
-    SPIDER_DB_HS_STRING_REF_BUFFER *keys,
-    int limit,
-    int skip,
-    st_spider_db_request_key *request_key
-  );
-  int append_insert(
-    uint handler_id,
-    SPIDER_DB_HS_STRING_REF_BUFFER *upds,
-    st_spider_db_request_key *request_key
-  );
-  int append_update(
-    uint handler_id,
-    spider_string *sql,
-    SPIDER_DB_HS_STRING_REF_BUFFER *keys,
-    SPIDER_DB_HS_STRING_REF_BUFFER *upds,
-    int limit,
-    int skip,
-    bool increment,
-    bool decrement,
-    st_spider_db_request_key *request_key
-  );
-  int append_delete(
-    uint handler_id,
-    spider_string *sql,
-    SPIDER_DB_HS_STRING_REF_BUFFER *keys,
-    int limit,
-    int skip,
-    st_spider_db_request_key *request_key
-  );
-  void reset_request_queue();
-#endif
   size_t escape_string(
     char *to,
     const char *from,
@@ -628,8 +566,6 @@ public:
   );
   uint get_lock_table_hash_count();
   void reset_lock_table_hash();
-  uint get_opened_handler_count();
-  void reset_opened_handler();
   void set_dup_key_idx(
     ha_spider *spider,
     int link_idx
@@ -676,9 +612,7 @@ public:
   spider_string      *db_names_str;
   /* fixme: this field looks useless */
   spider_string      *db_table_str;
-#ifdef SPIDER_HAS_HASH_VALUE_TYPE
   my_hash_value_type *db_table_str_hash_value;
-#endif
   uint               table_nm_max_length;
   uint               db_nm_max_length;
   spider_string      *column_name_str;
@@ -718,16 +652,12 @@ public:
     int *table_name_pos
   );
   bool need_change_db_table_name();
-#ifdef SPIDER_HAS_DISCOVER_TABLE_STRUCTURE
   int discover_table_structure(
     SPIDER_TRX *trx,
     SPIDER_SHARE *spider_share,
     spider_string *str
   );
-#endif
-#ifdef HA_HAS_CHECKSUM_EXTENDED
   bool checksum_support();
-#endif
 protected:
   int create_table_names_str();
   void free_table_names_str();
@@ -804,9 +734,6 @@ protected:
   spider_string           *exec_ha_sql;
   bool                    reading_from_bulk_tmp_table;
   bool                    filled_up;
-#if defined(HS_HAS_SQLCOM) && defined(HAVE_HANDLERSOCKET)
-  SPIDER_DB_HS_STRING_REF_BUFFER hs_upds;
-#endif
   SPIDER_INT_HLD          *union_table_name_pos_first;
   SPIDER_INT_HLD          *union_table_name_pos_current;
 public:
@@ -913,19 +840,10 @@ public:
   int append_delete(
     spider_string *str
   );
-  #if defined(HS_HAS_SQLCOM) && defined(HAVE_HANDLERSOCKET)
-  #ifdef HANDLER_HAS_DIRECT_UPDATE_ROWS
-  int append_increment_update_set_part();
-  int append_increment_update_set(
-    spider_string *str
-  );
-  #endif
-  #endif
   int append_update_set_part();
   int append_update_set(
     spider_string *str
   );
-  #ifdef HANDLER_HAS_DIRECT_UPDATE_ROWS
   int append_direct_update_set_part();
   int append_direct_update_set(
     spider_string *str
@@ -944,7 +862,6 @@ public:
     const char *alias,
     uint alias_length
   );
-  #endif
   int append_select_part(
     ulong sql_type
   );
@@ -1141,7 +1058,6 @@ public:
     const char *alias,
     uint alias_length
   );
-#ifdef HANDLER_HAS_DIRECT_AGGREGATE
   int append_sum_select_part(
     ulong sql_type,
     const char *alias,
@@ -1152,14 +1068,12 @@ public:
     const char *alias,
     uint alias_length
   );
-#endif
   void set_order_pos(
     ulong sql_type
   );
   void set_order_to_pos(
     ulong sql_type
   );
-#ifdef HANDLER_HAS_DIRECT_AGGREGATE
   int append_group_by_part(
     const char *alias,
     uint alias_length,
@@ -1170,7 +1084,6 @@ public:
     const char *alias,
     uint alias_length
   );
-#endif
   int append_key_order_for_merge_with_alias_part(
     const char *alias,
     uint alias_length,
@@ -1263,26 +1176,6 @@ public:
     spider_string *str,
     uint multi_range_cnt
   );
-  int append_open_handler_part(
-    ulong sql_type,
-    uint handler_id,
-    SPIDER_CONN *conn,
-    int link_idx
-  );
-  int append_open_handler(
-    spider_string *str,
-    uint handler_id,
-    SPIDER_CONN *conn,
-    int link_idx
-  );
-  int append_close_handler_part(
-    ulong sql_type,
-    int link_idx
-  );
-  int append_close_handler(
-    spider_string *str,
-    int link_idx
-  );
   int append_insert_terminator_part(
     ulong sql_type
   );
@@ -1451,30 +1344,11 @@ public:
   int reset_sql(
     ulong sql_type
   );
-#if defined(HS_HAS_SQLCOM) && defined(HAVE_HANDLERSOCKET)
-  int reset_keys(
-    ulong sql_type
-  );
-  int reset_upds(
-    ulong sql_type
-  );
-  int reset_strs(
-    ulong sql_type
-  );
-  int reset_strs_pos(
-    ulong sql_type
-  );
-  int push_back_upds(
-    SPIDER_HS_STRING_REF &info
-  );
-#endif
-#ifdef SPIDER_HAS_GROUP_BY_HANDLER
   int set_sql_for_exec(
     ulong sql_type,
     int link_idx,
     SPIDER_LINK_IDX_CHAIN *link_idx_chain
   );
-#endif
   int set_sql_for_exec(
     ulong sql_type,
     int link_idx
@@ -1512,11 +1386,9 @@ public:
   int show_records(
     int link_idx
   );
-#ifdef HA_HAS_CHECKSUM_EXTENDED
   int checksum_table(
     int link_idx
   );
-#endif
   int show_last_insert_id(
     int link_idx,
     ulonglong &last_insert_id
@@ -1567,20 +1439,9 @@ public:
     SPIDER_CONN *conn,
     int link_idx
   );
-  int insert_opened_handler(
-    SPIDER_CONN *conn,
-    int link_idx
-  );
-  int delete_opened_handler(
-    SPIDER_CONN *conn,
-    int link_idx
-  );
   int sync_from_clone_source(
     spider_db_handler *dbton_hdl
   );
-  bool support_use_handler(
-    int use_handler
-  );
   void minimum_select_bitmap_create();
   bool minimum_select_bit_is_set(
     uint field_index
@@ -1595,7 +1456,6 @@ public:
     int link_idx,
     ulong sql_type
   );
-#ifdef SPIDER_HAS_GROUP_BY_HANDLER
   int append_from_and_tables_part(
     spider_fields *fields,
     ulong sql_type
@@ -1662,8 +1522,6 @@ public:
     bool use_fields,
     spider_fields *fields
   );
-#endif
-#ifdef HANDLER_HAS_DIRECT_UPDATE_ROWS
   bool check_direct_update(
     st_select_lex *select_lex,
     longlong select_limit,
@@ -1674,7 +1532,6 @@ public:
     longlong select_limit,
     longlong offset_limit
   );
-#endif
 };
 
 class spider_mysql_handler: public spider_mbase_handler
